@@ -216,7 +216,9 @@ void KaspaBase::deleteAuthor(Oid author) {
 	if(isLocked(author)) throw BaseDeleteLock("Can't delete records - one is locked!");
   try {
     exec("begin");
-    Str where="where author_no="; where+=author;
+    Str where;
+    where="where author_no="; 
+    where+=author;
     deletePublAuthor(where);
     deletePartAuthor(where);
     where="where no="; where+=author;
@@ -629,7 +631,7 @@ void KaspaBase::updatePubl(PublRec *publ, const char *where, bool block) {
 /*************************************************************************
  *  Note
  **************************************************************************/
-Oid KaspaBase::newNote(Oid o=InvalidOid) {
+Oid KaspaBase::newNote(Oid o) {
   Oid ret;
   try {
     exec("begin");
@@ -1092,7 +1094,8 @@ void KaspaBase::newPublAuthor(Oid publ, Oid author) {
     s="select count(*) as c from publication_author where publication_no=";
     oid2str(publ, &s);
     exec(s);
-    Str c=getValue(0, "c");
+    Str c;
+    c=getValue(0, "c");
 
     s="insert into publication_author (publication_no, author_no, author_order, created, modified) values (";
     oid2str(publ, &s);
@@ -1176,7 +1179,8 @@ void KaspaBase::deletePublAuthor(const char *where) {
 }
 
 void KaspaBase::deletePublAuthor(Oid publ, Oid author) {
-  Str where="where publication_no="; where+=publ; where+=" and author_no="; where+=author;
+  Str where;
+  where="where publication_no="; where+=publ; where+=" and author_no="; where+=author;
 	if(isLocked("publication_author", where)) throw BaseDeleteLock("Can't delete records - one is locked!");
   try {
     exec("begin");
@@ -1201,7 +1205,8 @@ void KaspaBase::newPartAuthor(Oid part, Oid author) {
     s="select count(*) as c from part_author where part_no=";
     oid2str(part, &s);
     exec(s);
-    Str c=getValue(0, "c");
+    Str c;
+    c=getValue(0, "c");
 
     s="insert into part_author (part_no, author_no, author_order, created, modified) values (";
     s+=part;
@@ -1255,7 +1260,8 @@ void KaspaBase::deletePartAuthor(const char *where) {
 }
 
 void KaspaBase::deletePartAuthor(Oid part, Oid author) {
-  Str where="where part_no="; where+=part; where+=" and author_no="; where+=author;
+  Str where;
+  where="where part_no="; where+=part; where+=" and author_no="; where+=author;
 	if(isLocked("part_author", where)) throw BaseDeleteLock("Can't delete records - one is locked!");
   try {
     exec("begin");
