@@ -25,7 +25,7 @@
 #include <qmessagebox.h>
 #include <qapplication.h>
 #include <qwhatsthis.h>
-#include <iostream.h>
+//#include <iostream.h>
 
 // include files for KDE
 #include <kiconloader.h>
@@ -149,27 +149,28 @@ bool idle(void) {
 													delete view; \
 										  	  view=0;
 
-KaspalisteApp::KaspalisteApp(): config(0L), view(0L)
+KaspalisteApp::KaspalisteApp(QString dbname): config(0L), view(0L)
 {
-	init();
+	init(dbname);
 	initBackForward();
 }
 
-KaspalisteApp::KaspalisteApp(QKaspaEvent *e): config(0L), view(0L)
+KaspalisteApp::KaspalisteApp(QKaspaEvent *e, QString dbname): config(0L), view(0L)
 {
-		init();
+		init(dbname);
 	  kapp->postEvent(this, e);
 }
 
-void KaspalisteApp::init() {
+void KaspalisteApp::init(QString dbname) {
 	tbdock=QMainWindow::Left;
   setXMLFile("kaspalisteui.rc");
   initAction();
   currenttools=0L;
   createGUI(0L);
+  db=dbname;
 
 	try {
-    conn=new Sql(DB_NAME);
+    conn=new Sql(dbname);
   }  catch (SqlConnectionErr) {
 		// Start postgres
 		throw;
@@ -540,6 +541,7 @@ void KaspalisteApp::setupView(const QPixmap &pm) {
 
 	menuBar()->repaint();
 	view->show();
+  view->setFocus();
 	view->setFields();
 
 	if(currenttools) {
@@ -569,7 +571,7 @@ void KaspalisteApp::slotPublisherOverview() {
 }
 
 void KaspalisteApp::slotJournalOverview() {
-  slotSetURL("kaspa://journaloverview#order by name", false);
+  slotSetURL("kaspa://journaloverview#order by serie", false);
 }
 
 void KaspalisteApp::slotNewAuthor() {
@@ -604,6 +606,7 @@ void KaspalisteApp::slotState() {
 bool KaspalisteApp::showAuthorOverview(KaspaURL url, const char *caption) {
   try {
 		if(!cleanupView()) return false;
+    emit setCaption(i18n("Author Overview"));
     view = new AuthorSelect(url, conn, caption?caption:"Authors", this);
 		setupView(selbackgr);
   }  catch(KaspaErr& err) {
@@ -616,6 +619,7 @@ bool KaspalisteApp::showAuthorOverview(KaspaURL url, const char *caption) {
 bool KaspalisteApp::showPublisherOverview(KaspaURL url, const char *caption) {
   try {
 		if(!cleanupView()) return false;
+    emit setCaption(i18n("Publisher Overview"));
     view = new PublisherSelect(url, conn, caption?caption:"Publisher", this);
 		setupView(selbackgr);
   }  catch(KaspaErr& err) {
@@ -629,6 +633,7 @@ bool KaspalisteApp::showPublisherOverview(KaspaURL url, const char *caption) {
 bool KaspalisteApp::showJournalOverview(KaspaURL url, const char *caption) {
   try {
 		if(!cleanupView()) return false;
+    emit setCaption(i18n("Journal Overview"));
     view = new JournalSelect(url, conn, caption?caption:"Journal", this);
 		setupView(selbackgr);
   }  catch(KaspaErr& err) {
@@ -642,6 +647,7 @@ bool KaspalisteApp::showJournalOverview(KaspaURL url, const char *caption) {
 bool KaspalisteApp::showPublOverview(KaspaURL url, const char *caption) {
   try {
 		if(!cleanupView()) return false;
+    emit setCaption(i18n("Publication Overview"));
     view = new PublSelect(url, conn, caption?caption:"Publications", this);
 		setupView(selbackgr);
   }  catch(KaspaErr& err) {
@@ -652,20 +658,10 @@ bool KaspalisteApp::showPublOverview(KaspaURL url, const char *caption) {
 }
 
 
-bool KaspalisteApp::showNoteOverview(KaspaURL url, const char *caption=0) {
-/*
-  try {
-		if(!cleanupView()) return false;
-    view = new NoteSelect(url, conn, caption?caption:"Links", this);
-		setupView(selbackgr);
-  }  catch(KaspaErr& err) {
-		HANDLE_CATCH(err);
-		return false;
-  }
-  return true;
-*/
+bool KaspalisteApp::showNoteOverview(KaspaURL url, const char *caption) {
   try {
 		if(!cleanupView()) return false;
+    emit setCaption(i18n("Note Overview"));
     view = new NoteOverview(url, conn, caption?caption:"Links", this);
 		setupView(selbackgr);
   }  catch(KaspaErr& err) {
@@ -702,7 +698,7 @@ bool KaspalisteApp::showPart(KaspaURL url) {
 
 bool KaspalisteApp::showPublication(KaspaURL url) {
   try {
-		debug("KaspalisteApp::showPublication() - url=%s", (const char *) url);
+//		debug("KaspalisteApp::showPublication() - url=%s", (const char *) url);
 		
 		if(!cleanupView()) return false;
     view = new Publication(url, conn, this, "Publication");
@@ -768,7 +764,6 @@ bool KaspalisteApp::showDataView(KaspaURL url) {
 bool KaspalisteApp::showPublisher(KaspaURL url) {
   try {
 		if(!cleanupView()) return false;
-
     view = new Publisher(url, conn, this, "Publisher");
 		setupView(publisherbackgr);
   } catch(KaspaErr& err) {
@@ -781,7 +776,6 @@ bool KaspalisteApp::showPublisher(KaspaURL url) {
 bool KaspalisteApp::showJournal(KaspaURL url) {
   try {
 		if(!cleanupView()) return false;
-
     view = new JournalView(url, conn, this, "Journal");
 		setupView(publisherbackgr);
   } catch(KaspaErr& err) {
@@ -795,7 +789,7 @@ bool KaspalisteApp::showJournal(KaspaURL url) {
 bool KaspalisteApp::showSearch(KaspaURL url) {
   try {
 		if(!cleanupView()) return false;
-
+    emit setCaption(i18n("Search"));
     view = new Search(url, conn, this, "Search");
 		setupView(searchbackgr); // <-- another Background???
   } catch(KaspaErr& err) {
@@ -809,6 +803,7 @@ bool KaspalisteApp::showSearch(KaspaURL url) {
 bool KaspalisteApp::showState(KaspaURL url) {
   try {
 		if(!cleanupView()) return false;
+    emit setCaption(i18n("State"));
     view = new State(url, conn, this, "State");
 		setupView(QPixmap());
   }  catch(KaspaErr& err) {
@@ -829,7 +824,7 @@ bool KaspalisteApp::event(QEvent *e) {
 		QKaspaEvent *k=static_cast<QKaspaEvent*>(e);
 		ASSERT(e);
 		KaspaURL url(k->url());
-		debug("KaspalisteApp::event(QEvent*) - url=%s", (const char *)url);
+//		debug("KaspalisteApp::event(QEvent*) - url=%s", (const char *)url);
 //		debug("KaspalisteApp::event(QEvent*) - table=%s", (const char *)url.table());
     if(!strcmp(url.table(), "author")) showAuthor(url);
 		else if(!strcmp(url.table(), "publication")) showPublication(url);
@@ -881,7 +876,7 @@ void KaspalisteApp::slotNextFocus() {
 }
 
 void KaspalisteApp::slotBack() {
-  qDebug("\nKaspalisteApp::slotBack() - count back=%i", back.count());
+//  qDebug("\nKaspalisteApp::slotBack() - count back=%i", back.count());
 	if(view && view->getState()!=INVALID)
 		forward.append(new QKaspaEvent(view->url(), view->caption()));
   QEvent *ev= back.getLast();
@@ -912,7 +907,7 @@ void KaspalisteApp::slotSetURL(const char *url, bool newwin, const char *caption
 	e->setUrl(url);
 	e->setCaption(caption);
 	if(newwin) {
-		KaspalisteApp* new_window= new KaspalisteApp(e);
+		KaspalisteApp* new_window= new KaspalisteApp(e, db);
 		new_window->show();
 	}
 	else {
@@ -926,7 +921,7 @@ void KaspalisteApp::slotNewWindow()
 {
   slotStatusMsg(i18n("Opening a new Application window..."));
 
-  KaspalisteApp* new_window=new KaspalisteApp();
+  KaspalisteApp* new_window=new KaspalisteApp(db);
   new_window->show();
 }
 
@@ -1020,6 +1015,10 @@ void KaspalisteApp::slotStatusHelpMsg(const char *text)
   statusBar()->message(text, 2000);
 }
 
+void KaspalisteApp::slotSetCaption(const char *text) {
+  setCaption(text);
+}
+
 void KaspalisteApp::slotSetToolbarURL(const QString& url) {
 	slotSetURL(url, false);
 }
@@ -1166,6 +1165,7 @@ void KaspalisteApp::slotReadOnlyGUI() {
 
 
 void KaspalisteApp::kaspaConnections(KaspaWidget *w) {
+	connect(w, SIGNAL(setCaption(const char*)), SLOT(slotSetCaption(const char *)));
 	connect(w, SIGNAL(statusMessage(const char*)), SLOT(slotStatusHelpMsg(const char *)));
 	connect(w, SIGNAL(enableCommand(int)), SLOT(slotEnableCommand(int)));
 	connect(w, SIGNAL(enableCommand(int,bool)), SLOT(slotEnableCommand(int,bool)));
@@ -1182,7 +1182,7 @@ void KaspalisteApp::kaspaConnections(KaspaWidget *w) {
 }
 
 void KaspalisteApp::slotCreateGUI(KParts::Part *part) {
-  cout << "slotCreateGUI()\n";
+//  cout << "slotCreateGUI()\n";
   createGUI(part);
 }
 
