@@ -115,7 +115,7 @@ Publication::Publication(KaspaURL url, Sql *conn, QWidget* parent,	const char* n
 	entrytype->insertItem("In Proceeding", 		BT_INPROCEEDING);
 	entrytype->insertItem("Article",					BT_ARTICLE);
 
-	debug("Publication::Publication(QString, QWidget, char*): url=%s", (const char *) url);
+//	debug("Publication::Publication(QString, QWidget, char*): url=%s", (const char *) url);
 	if(url.command()=="new")
 	  publ = new PublBase(conn);
 	else
@@ -149,7 +149,7 @@ Publication::Publication(KaspaURL url, Sql *conn, QWidget* parent,	const char* n
 
 Publication::~Publication()
 {
-	debug("Publication::~Publication()");
+//	debug("Publication::~Publication()");
 	delete publ;
 }
 
@@ -176,6 +176,7 @@ void Publication::setFields() {
   if(isValid()) {
 		try  {
 			setWorkingGUI();
+      emit setCaption(publ->getTitle());
 	  	title->setText(publ->getTitle());
 		  memo->setText(QCString(publ->getMemo()));
 	  	year->setText(publ->getYear());
@@ -337,7 +338,7 @@ void Publication::remAuthor() {
 void Publication::showBiblio() {
 	try {
 		save(true);
-		debug("Publication::showBiblio() - url=%s", url());
+//		debug("Publication::showBiblio() - url=%s", url());
 		QString s("kaspa://bibliography#where publication.no=");
 		s+=QString().setNum(publ->id());
 		requestURL(s, false);
@@ -428,44 +429,44 @@ void Publication::showLinks() {
 
 KToolBar *Publication::getToolBar() {
 	KaspaToolBar *toolbar = new KaspaToolBar(topLevelWidget());
-  toolbar->insertButton(BarIcon("showbiblio.xpm"), ID_PUBL_SHOWBIBLIO, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("showbiblio.png"), ID_PUBL_SHOWBIBLIO, SIGNAL(clicked()),
 				this, SLOT(showBiblio()), true, i18n("Show Bibligraphy") );
-  toolbar->insertButton(BarIcon("showpublisher.xpm"), ID_PUBL_SHOWPUBLISHER, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("showpublisher.png"), ID_PUBL_SHOWPUBLISHER, SIGNAL(clicked()),
 				this, SLOT(showPublisherOrJournal()), true, i18n("Show Publisher/Journal") );
-  toolbar->insertButton(BarIcon("showlinks.xpm"), ID_PUBL_SHOWLINKS, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("showlinks.png"), ID_PUBL_SHOWLINKS, SIGNAL(clicked()),
 				this, SLOT(showLinks()), true, i18n("Show Links") );
 
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("newauthor.xpm"), ID_PUBL_NEWAUTHOR, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("newauthor.png"), ID_PUBL_NEWAUTHOR, SIGNAL(clicked()),
 				this, SLOT(newAuthor()), true, i18n("New Author") );
-  toolbar->insertButton(BarIcon("insauthor.xpm"), ID_PUBL_INSAUTHOR, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("insauthor.png"), ID_PUBL_INSAUTHOR, SIGNAL(clicked()),
 				this, SLOT(insAuthor()), true, i18n("Insert Author") );
-  toolbar->insertButton(BarIcon("delauthor.xpm"), ID_PUBL_REMAUTHOR, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("delauthor.png"), ID_PUBL_REMAUTHOR, SIGNAL(clicked()),
 				this, SLOT(remAuthor()), true, i18n("Delete Author") );
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("newnote.xpm"), ID_PUBL_NEWLINK, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("newnote.png"), ID_PUBL_NEWLINK, SIGNAL(clicked()),
 				this, SLOT(newLink()), true, i18n("New Note") );
-  toolbar->insertButton(BarIcon("insnote.xpm"), ID_PUBL_INSLINK, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("insnote.png"), ID_PUBL_INSLINK, SIGNAL(clicked()),
 				this, SLOT(insLink()), true, i18n("Insert Note") );
-  toolbar->insertButton(BarIcon("delnote.xpm"), ID_PUBL_REMLINK, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("delnote.png"), ID_PUBL_REMLINK, SIGNAL(clicked()),
 				this, SLOT(remLink()), true, i18n("Delete Note") );
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("newpublisher.xpm"), ID_PUBL_NEWPUBLISHER, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("newpublisher.png"), ID_PUBL_NEWPUBLISHER, SIGNAL(clicked()),
 				this, SLOT(newPublisherOrJournal()), true, i18n("New Publisher/Journal") );
-  toolbar->insertButton(BarIcon("inspublisher.xpm"), ID_PUBL_INSPUBLISHER, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("inspublisher.png"), ID_PUBL_INSPUBLISHER, SIGNAL(clicked()),
 				this, SLOT(insPublisherOrJournal()), true, i18n("Insert Publisher/Journal") );
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("newpart.xpm"), ID_PUBL_NEWPART, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("newpart.png"), ID_PUBL_NEWPART, SIGNAL(clicked()),
 				this, SLOT(newPart()), true, i18n("New Part") );
-  toolbar->insertButton(BarIcon("delpart.xpm"), ID_PUBL_REMPART, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("delpart.png"), ID_PUBL_REMPART, SIGNAL(clicked()),
 				this, SLOT(remPart()), true, i18n("Remove Part") );
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("filedel.xpm"), ID_PUBL_DELREC, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("filedel.png"), ID_PUBL_DELREC, SIGNAL(clicked()),
 				this, SLOT(del()), true, i18n("Delete Record") );
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("filefloppy.xpm"), ID_PUBL_FLUSH, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("filefloppy.png"), ID_PUBL_FLUSH, SIGNAL(clicked()),
 				this, SLOT(flush()), true, i18n("Save Changes") );
-  toolbar->insertButton(BarIcon("reload.xpm"), ID_PUBL_RESET, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("reload.png"), ID_PUBL_RESET, SIGNAL(clicked()),
 				this, SLOT(reread()), true, i18n("Revert Record") );
 	toolbar->setBarPos(KToolBar::Top);
 	toolbar->enable(KToolBar::Show);
